# Security Policy

Security is always an important considerationfor any project, especially in software development. BoogiePi was originally designed to run in a hobiest environment on a low-power SOC. The library is still very much in an alpha form at this time and should not be used in a production environment.  

As the project matures and we begin to move towards a more accessible and structured framework more time and energy will be spent on security and error management. When the project evolves to release version *1.x* it will exit the alpha testing phase and the project will be considered ready for more stable environments.  

We do our best to read and respond to all properly submitted issues in a timely manner. Security issues take precedence over general bugs and will be addressed as swiftly as possible in order to preserve the integrity of the project.


## Supported Versions

The following versions are approved for security patches:

| Version | Supported          |
| ------- | ------------------ |
| 1.1 +   | :heavy_check_mark: |
| 1.0.x   | :heavy_check_mark: |
| < 1.0   | :x:                |

## Reporting a Vulnerability

Vulnerabilities can be reported in the issue tracker:

[BoogiePi Issue Tracker](https://github.com/BoogieMobile/boogiepi/issues)

If you need to report a serious or sensitive vulnerability, you can do so privately via our project email:  

<boogiepi@boogiemobile.net>

Please only use this address to report vulnerabilities that are too sensitive or dangerous to report via the GitHub issue tracker.  


## Liabilities

BoogieMobile and all project maintainers and contributers will not be liable for any losses or damage in connection with the use of the BoogiePi library.  

Any use of this project or the software contained within, whether as intended or outside the scope of the project guidelines, is done "at your own risk."  

While we are confident with the quality and reliability of the BoogiePi library, the project is still in alpha testing and should be considered unstable and not safe for use on production systems.  

Abuse of the issue tracker or any other parts of this project is against our community guidelines and can result in banning and/or other actions against the offender.  
